@@ -24,12 +24,12 @@ lslx$set("private",
            }
            
            if (missing(group)) {
-             group <-  private$model$name_group
-           } else if (!all(group %in% private$model$name_group)) {
+             group <-  private$model$level_group
+           } else if (!all(group %in% private$model$level_group)) {
              stop(
                "Argument 'group' contains unknown group name.",
                "\n  Group name(s) currently recognized by 'lslx' is ",
-               do.call(paste, as.list(private$model$name_group)),
+               do.call(paste, as.list(private$model$level_group)),
                ".",
                "\n  Group name(s) specified in 'group' is ",
                do.call(paste, as.list(group)),
